@@ -18,19 +18,20 @@
 #ifndef KEDUCA_H
 #define KEDUCA_H
 
+/*
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
-
-#include "keducaview.h"
+*/
 
 #include <kapplication.h>
-#include <kmainwindow.h>
+#include <kparts/mainwindow.h>
+#include <kparts/part.h>
 #include <kaction.h>
 
 /** The KEduca TestMaster.
     This will execute the Test/Examen as defined by the KEduca Document. */
-class Keduca : public KMainWindow
+class Keduca : public KParts::MainWindow
 {
     Q_OBJECT
 
@@ -43,13 +44,8 @@ public:
   void initGallery(const KURL &urlFile=KURL());
 
 private:
-
-    // Private methods
-
-    /** Init graphical interface */
-    void init();
-    /** Init menu bar settings */
-    void initMenuBar();
+    /** Configures the actions */
+    void setupActions();
     /** Write settings */
     void configWrite();
     /** Read settings */
@@ -62,7 +58,7 @@ private:
     /** Recent files */
     KRecentFilesAction *_recentFiles;
     /** A KEDUCA file main view */
-    KEducaView *_mainView;
+    KParts::ReadOnlyPart *_part;
 
 public slots:
     /** Open a file */
@@ -72,11 +68,9 @@ public slots:
 
 private slots:
     /** Close actual document */
-    void slotFileClose();
-    /** Configure keduca */
-    void slotConfigure();
-  /** Open gallery dialog */
-  void slotGallery();
+    /*void slotFileClose();*/
+    /** Open gallery dialog */
+    void slotGallery();
 };
 
 #endif
