@@ -41,7 +41,7 @@ KGroupEduca::~KGroupEduca(){
 }
 
 /** Insert a check or radio button */
-void KGroupEduca::insertAnswer( QString text)
+void KGroupEduca::insertAnswer( const QString& text)
 {
     QButton *answer = 0;
 
@@ -57,7 +57,7 @@ void KGroupEduca::insertAnswer( QString text)
     answer->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)0 ) );
     answer->setText( text );
     answer->show();
-    this->insert(answer);
+    insert(answer);
 }
 
 /** Set type */
@@ -69,12 +69,12 @@ void KGroupEduca::setType(ButtonType type)
 /** Clear all kradio or kcheck answers */
 void KGroupEduca::clearAnswers()
 {
-    unsigned int maxButton = this->count();
+    unsigned int maxButton = count();
     for( unsigned int i=0 ; i<maxButton ; ++i )
     {
         QButton *tmpButton;
-        if( (tmpButton = this->find(i)) )
-            this->remove(tmpButton);
+        if( (tmpButton = find(i)) )
+            remove(tmpButton);
         delete tmpButton;
     }
 
@@ -87,13 +87,13 @@ bool KGroupEduca::isChecked(int id)
     {
     case Radio:
     {
-        KRadioEduca *tmpRadioButton = (KRadioEduca*) this->find(id);
+        KRadioEduca *tmpRadioButton = (KRadioEduca*) find(id);
         if(tmpRadioButton != 0) return tmpRadioButton->isChecked();
     }
     break;
     case Check:
     {
-        KCheckEduca *tmpCheckButton = (KCheckEduca*) this->find(id);
+        KCheckEduca *tmpCheckButton = (KCheckEduca*) find(id);
         if(tmpCheckButton != 0) return tmpCheckButton->isChecked();
     }
     break;
