@@ -34,7 +34,7 @@ public:
     KGroupEduca(QWidget *parent=0, const char *name=0);
     ~KGroupEduca();
     /** Insert a check or radio button */
-    void insertAnswer( QString text);
+    void insertAnswer( const QString& text);
     /** Set type */
     void setType(ButtonType Type);
     /** Clear all kradio or kcheck answers */
