@@ -3,7 +3,7 @@
                              -------------------
     begin                : Wed Sep 6 2000
     copyright            : (C) 2000 by Javier Campos Morales
-    email                : javi_c@ctv.es
+    email                : javi@asyris.org
 ***************************************************************************/
 
 /***************************************************************************
@@ -18,7 +18,6 @@
 #ifndef KRADIOEDUCA_H
 #define KRADIOEDUCA_H
 
-#include <qwidget.h>
 
 #include <qradiobutton.h>
 #include <qsimplerichtext.h>
@@ -26,7 +25,6 @@
 /**QRadioButton with wordwrap and richtext features
  *@author Javier Campos Morales
  */
-
 class KRadioEduca : public QRadioButton {
     Q_OBJECT
 
@@ -34,13 +32,20 @@ public:
     KRadioEduca(QWidget *parent=0, const char *name=0);
     ~KRadioEduca();
 
-private: // Private attributes
+protected:
+
+    // Protected methods
+
+    /** reimpl */
+    void drawButtonLabel( QPainter *p);
+
+private:
+
+    // Private attributes
+
     /** Rich Text */
     QSimpleRichText *_doc;
 
-protected: // Protected methods
-    /** reimpl */
-    void drawButtonLabel( QPainter *p);
 };
 
 #endif
