@@ -53,20 +53,20 @@ void KControlAddEdit::init(FileRead *keducaFile, bool edit)
     
     if( _editMode )
     {
-        this->setCaption(i18n("Modify Question"));
+        setCaption(i18n("Modify Question"));
         fillPage();
     }else{
-        this->setCaption(i18n("Add Questions"));
+        setCaption(i18n("Add Questions"));
         slotQuestionTypeChanged( 0 );
     }
 
     // settings for Question page
-    this->setHelpEnabled ( _pageQuestion, false );
-    this->setNextEnabled( _pageQuestion, false );
+    setHelpEnabled ( _pageQuestion, false );
+    setNextEnabled( _pageQuestion, false );
 
     // settings for Answer page
-    this->setHelpEnabled ( _pageAnswer, false );
-    this->setFinishEnabled( _pageAnswer, true );
+    setHelpEnabled ( _pageAnswer, false );
+    setFinishEnabled( _pageAnswer, true );
 }
 
 /** Fill page of current record */
@@ -198,7 +198,7 @@ void KControlAddEdit::accept()
 
     addQuestion();
     configWrite();
-    this->done( QDialog::Accepted );
+    done( QDialog::Accepted );
 }
 
 /** Add question with form data */
@@ -228,7 +228,7 @@ void KControlAddEdit::configRead()
     KConfig *config = KGlobal::config();
     config->setGroup("AddModify Window");
     QSize defaultSize(500,400);
-    this->resize( config->readSizeEntry("Geometry", &defaultSize ) );
+    resize( config->readSizeEntry("Geometry", &defaultSize ) );
 }
 
 /** Write config settings */
@@ -236,18 +236,18 @@ void KControlAddEdit::configWrite()
 {
     KConfig *config = KGlobal::config();
     config->setGroup("AddModify Window");
-    config->writeEntry("Geometry", this->size() );
+    config->writeEntry("Geometry", size() );
     config->sync();
 }
 
 /** Question data changed */
 void KControlAddEdit::slotDataChanged()
 {
-    if( _pageQuestion == this->currentPage() )
+    if( _pageQuestion == currentPage() )
     {
         nextButton()->setEnabled( !_questionText->text().isEmpty() );
     }
-    if( _pageAnswer == this->currentPage() )
+    if( _pageAnswer == currentPage() )
     {
         _buttonInsert->setEnabled( !_answerText->text().isEmpty() );
     }
