@@ -21,11 +21,13 @@
 
 #include <kio/netaccess.h>
 #include <kstandarddirs.h>
+#include <kmimetype.h>
 #include <kdebug.h>
 #include <ktempfile.h>
 
 #include <qfileinfo.h>
 #include <qpixmap.h>
+#include <qbuffer.h>
 
 FileRead::FileRead( QObject *parent, const char *name )
     :QObject(parent, name),
@@ -56,17 +58,29 @@ bool FileRead::openFile(const KURL &url) {
     return returnval;
 }
 
-bool FileRead::loadFile( const QString &filename )
+bool FileRead::loadFile(const QString &filename)
 {
     QDomDocument doc("document.xml");
 
+    KMimeType::Ptr type = KMimeType::findByFileContent(filename);
+
+	kdDebug() << "FileRead::loadFile(): MIME-Type is " << type->name() << endl;
+
     QFile file(filename);
 
     if(!file.open(IO_ReadOnly))
     {
         return false;
     }
-    doc.setContent( &file );
+
+    if (type->name() == "text/html") // Non-compressed files are recognized as HTML...
+    {
+        doc.setContent(&file);
+    }
+    else
+    {
+        doc.setContent(qUncompress(file.readAll()));
+    }
 
      QDomElement docElem = doc.documentElement();
    if( (doc.doctype().isNull()) || (doc.doctype().name() != "educa") )   { 
@@ -148,7 +162,7 @@ bool FileRead::loadFile( const QString &filename )
     return true;
 }
 
-void FileRead::setQuestion( QuestionField field, QString text)
+void FileRead::setQuestion( QuestionField field, const QString& text)
 {
 // QF_text, QF_picture, QF_type, QF_time, QF_tip, QF_explain
     switch( field )
@@ -192,7 +206,7 @@ void FileRead::setQuestion( QuestionField field, int value )
     _changed=true;
 }
 
-void FileRead::setResult( ResultField field, QString text)
+void FileRead::setResult( ResultField field, const QString& text)
 {
 // RS_text, QF_picture
     switch( field )
@@ -227,7 +241,7 @@ void FileRead::setResult( ResultField field, int value )
     _changed=true;
 }
 
-void FileRead::setAnswer( QString text, bool value, int points)
+void FileRead::setAnswer( const QString& text, bool value, int points)
 {
     Answers tmpAnswers;
 
@@ -545,8 +559,8 @@ QString FileRead::getPicture()
 {
   QString picture;
 
-    if( !this->getQuestion(QF_PICTURE).isEmpty() )
-      picture = this->getQuestion(QF_PICTURE);
+    if( !getQuestion(QF_PICTURE).isEmpty() )
+      picture = getQuestion(QF_PICTURE);
       else if( !(_header["image"]).isEmpty() )
         picture = _header["image"];
           else
@@ -623,7 +637,7 @@ void FileRead::recordSwap( bool moveup )
     _changed=true;
 }
 
-bool FileRead::saveFile( const KURL &url, bool copyimages )
+bool FileRead::saveFile( const KURL &url, bool copyimages, bool saveCompressed )
 {
     if (url.isValid())
     {
@@ -639,7 +653,7 @@ bool FileRead::saveFile( const KURL &url, bool copyimages )
              delete _tmpfile;
              _tmpfile = 0;
         }
-        if( saveFile(_currentURL.path(), copyimages) ) {
+        if( saveFile(_currentURL.path(), copyimages, saveCompressed) ) {
             emit completed();
             emit setWindowCaption( _currentURL.prettyURL() );
             return true;
@@ -653,7 +667,7 @@ bool FileRead::saveFile( const KURL &url, bool copyimages )
              _tmpfile = new KTempFile;
         }
         // otherwise, we already had a temp file
-        if( saveFile(_tmpfile->name(), copyimages) ) {
+        if( saveFile(_tmpfile->name(), copyimages, saveCompressed) ) {
             // upload the file
              KIO::Job * job = KIO::file_copy( KURL::fromPathOrURL( _tmpfile->name() ), _currentURL, -1, true /*overwrite*/ );
              connect( job, SIGNAL( result( KIO::Job * ) ), this, SLOT( slotUploadFinished (KIO::Job *) ) );
@@ -665,14 +679,23 @@ bool FileRead::saveFile( const KURL &url, bool copyimages )
     return false;
 }
 
-bool FileRead::saveFile( const QString &filename, bool copyimages )
+bool FileRead::saveFile( const QString &filename, bool copyimages, bool saveCompressed )
 {
     QDomDocument doc("document.xml");
     QTextStream stream;
     QString line;
+    QByteArray data;
+    QBuffer buffer(data);
     QFile file(filename);
     QStringList copyJOB;
-    
+
+    stream.setDevice(&buffer);
+
+    if ( (!file.open(IO_WriteOnly)) || (!buffer.open(IO_WriteOnly)) )
+    {
+        return false;
+    }
+    /*
     stream.setDevice(&file);
 
     if(!file.open(IO_WriteOnly))
@@ -680,6 +703,7 @@ bool FileRead::saveFile( const QString &filename, bool copyimages )
         // No puede abrir la base
         return false;
     }
+    */
 
     QString head( "<?xml version='1.0' encoding='UTF-8' standalone='yes' ?><!DOCTYPE educa>" );
     doc.setContent( head );
@@ -770,6 +794,11 @@ bool FileRead::saveFile( const QString &filename, bool copyimages )
     }
 
     doc.save( stream, 4);
+    buffer.close();
+    if ( saveCompressed )
+        file.writeBlock(qCompress(data));
+    else
+        file.writeBlock(data);
     file.close();
 
     if( copyimages == true && copyJOB.count() > 0 )
