@@ -12,22 +12,30 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
+
 #include "khangman.h"
 #include "version.h"
 
-#include <dcopclient.h>
+#include <kapplication.h>
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
+#include <klocale.h>
+#include <kprocess.h>
+#include <kstandarddirs.h>
+
+#include "fontchecker.h"
 
 static const char description[] =
     I18N_NOOP("Classical hangman game for KDE");
 
+static const char version[] = "0.1";
+
 static KCmdLineOptions options[] =
 {
-    { "+[URL]", I18N_NOOP( "Document to open" ), 0 },
+//    { "+[URL]", I18N_NOOP( "Document to open" ), 0 },
     KCmdLineLastOption
 };
 
@@ -35,7 +43,8 @@ int main(int argc, char **argv)
 {
     KAboutData aboutData( "khangman", I18N_NOOP("KHangMan"),
                               KHM_VERSION, description, KAboutData::License_GPL,
-                              "(c) 2001-2003, Anne-Marie Mahfouf", 0, "http://edu.kde.org/khangman");
+                              "(c) 2001-2006, Anne-Marie Mahfouf", 0,
+"http://edu.kde.org/khangman");
     aboutData.addAuthor("Primoz Anzur", I18N_NOOP("Previous maintainer"), "zerokode@gmx.net");
     //write the names with accents and all and this file save with utf8 encoding
     aboutData.addAuthor("Anne-Marie Mahfouf", I18N_NOOP("Actual maintainer, author"), "annma@kde.org");
@@ -94,42 +103,53 @@ int main(int argc, char **argv)
     aboutData.addCredit("Lubos Lunàk",
                             I18N_NOOP("Coding help"), "l.lunak@kde.org");
     aboutData.addCredit("Albert Astals Cid",
-                            I18N_NOOP("Coding help"), "tsdgeos@terra.es");
+                            I18N_NOOP("Coding help, fixed a lot of things"), "tsdgeos@terra.es");
    aboutData.addCredit("Danny Allen",
-                             I18N_NOOP("svg icon"), "danny@dannyallen.co.uk");
+                             I18N_NOOP("SVG icon"), "danny@dannyallen.co.uk");
    aboutData.addCredit("Peter Hedlund",
-                             I18N_NOOP("Code for generating icons for the characters toolbar"), "peter@peterandlinda.com");
-
+                             I18N_NOOP("Code for generating icons for the characters toolbar"), "peter.hedlund@kdemail.net");
+    aboutData.addCredit("Inge Wallin",
+                             I18N_NOOP("Code cleaning"), "inge@lysator.liu.se");
     KCmdLineArgs::init( argc, argv, &aboutData );
-    KCmdLineArgs::addCmdLineOptions(options);
+    KCmdLineArgs::addCmdLineOptions( options );
     KApplication app;
+    KHangMan *mainWin = 0;
 
-    // register ourselves as a dcop client
-    app.dcopClient()->registerAs(app.name(), false);
-
-    // see if we are starting with session management
-    if (app.isRestored())
-        RESTORE(KHangMan)
-    else
+    QFont f("Domestic Manners", 12, QFont::Normal, true);
+    QFont fd("Dustismo Roman", 12, QFont::Normal, true);
+    if (!fontChecker::checkInstalled(f, locate("appdata", "fonts/Domestic_Manners.ttf")))
     {
-        // no session.. just start up normally
-        KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
-        if (args->count() == 0)
-        {
-            KHangMan *widget = new KHangMan;
-            widget->show();
-        }
-        else
-        {
-            int i = 0;
-            for (; i < args->count(); i++)
+            KProcess *proc = new KProcess;
+            for (int i = 0; i < argc; i++) *proc << argv[i];
+            proc->start();
+    }
+    else if (!fontChecker::checkInstalled(fd, locate("appdata", "fonts/Dustismo_Roman.ttf")))
+    {
+        KProcess *proc = new KProcess;
+        for (int i = 0; i < argc; i++) *proc << argv[i];
+        proc->start();
+    }
+    else 
+    {
+            if (app.isRestored())
             {
-                KHangMan *widget = new KHangMan;
-                widget->show();
+                RESTORE(KHangMan);
             }
-        }
-        args->clear();
+            else
+            {
+                // no session.. just start up normally
+                KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+        
+                /// @todo do something with the command line args here
+        
+                mainWin = new KHangMan();
+                app.setMainWidget( mainWin );
+                mainWin->show();
+        
+                args->clear();
+                // mainWin has WDestructiveClose flag by default, so it will delete itself.
+                return app.exec();
+                }
     }
-
-    return app.exec();
 }
+
