@@ -12,8 +12,8 @@
 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+// 02110-1301, USA.
 
 #ifndef KIG_MISC_OBJECT_HIERARCHY_H
 #define KIG_MISC_OBJECT_HIERARCHY_H
@@ -49,8 +49,12 @@ private:
 
   void init( const std::vector<ObjectCalcer*>& from, const std::vector<ObjectCalcer*>& to );
 
-  // this constructor is private since it should be used only by the static
-  // constructor buildSafeObjectHierarchy
+  /**
+   * this constructor is private since it should be used only by the static
+   * constructor buildSafeObjectHierarchy
+   *
+   * \see ObjectHierarchy::buildSafeObjectHierarchy
+   */
   ObjectHierarchy();
 
 public:
@@ -60,33 +64,39 @@ public:
   ObjectHierarchy( const ObjectHierarchy& h );
   ~ObjectHierarchy();
 
-  // this creates a new ObjectHierarchy, that takes a.size() less
-  // arguments, but uses copies of the ObjectImp's in a instead..
+  /**
+   * this creates a new ObjectHierarchy, that takes a.size() less
+   * arguments, but uses copies of the ObjectImp's in \p a instead..
+   */
   ObjectHierarchy withFixedArgs( const Args& a ) const;
 
   std::vector<ObjectImp*> calc( const Args& a, const KigDocument& doc ) const;
 
-  // saves the ObjectHierarchy data in children xml tags of parent..
+  /**
+   * saves the ObjectHierarchy data in children xml tags of \p parent ..
+   */
   void serialize( QDomElement& parent, QDomDocument& doc ) const;
   /**
-   * Deserialize the ObjectHierarchy data from the xml element parent..
+   * Deserialize the ObjectHierarchy data from the xml element \p parent ..
    * Since this operation can fail for some reasons, we provide it as a
    * static to return 0 in case of error.
    */
-  static ObjectHierarchy* ObjectHierarchy::buildSafeObjectHierarchy( const QDomElement& parent, QString& error );
+  static ObjectHierarchy* buildSafeObjectHierarchy( const QDomElement& parent, QString& error );
 //  ObjectHierarchy( const QDomElement& parent );
 
-  // build a set of objects that interdepend according to this
-  // ObjectHierarchy..  Only the result objects are returned.  Helper
-  // objects that connect the given objects with the returned objects,
-  // can only be found by following the returned objects' parents()
-  // methods..
+  /**
+   * build a set of objects that interdepend according to this
+   * ObjectHierarchy..  Only the result objects are returned.  Helper
+   * objects that connect the given objects with the returned objects,
+   * can only be found by following the returned objects' parents()
+   * methods..
+   */
   std::vector<ObjectCalcer*> buildObjects( const std::vector<ObjectCalcer*>& os, const KigDocument& ) const;
 
   ArgsParser argParser() const;
 
-  uint numberOfArgs() const { return mnumberofargs; };
-  uint numberOfResults() const { return mnumberofresults; };
+  uint numberOfArgs() const { return mnumberofargs; }
+  uint numberOfResults() const { return mnumberofresults; }
 
   const ObjectImpType* idOfLastResult() const;
 
