@@ -59,6 +59,7 @@ BaseConstructMode::BaseConstructMode( KigPart& d )
 
 BaseConstructMode::~BaseConstructMode()
 {
+  delete mcursor;
 //  delete mcursorholder;
 }
 
@@ -96,6 +97,7 @@ void BaseConstructMode::leftReleased( QMouseEvent* e, KigWidget* v )
     }
   }
   leftClickedObject( o, e->pos(), *v, keyCtrlOrShift );
+  KigMode::leftReleased( e, v );
 }
 
 void BaseConstructMode::leftClickedObject(
@@ -149,6 +151,7 @@ void BaseConstructMode::leftClickedObject(
     mcursor = ObjectFactory::instance()->cursorPointCalcer( w.fromScreen( p ) );
 //    mcursor = ObjectFactory::instance()->sensiblePointCalcer( w.fromScreen( p ), mdoc.document(), w );
     mcursor->calc( mdoc.document() );
+    delete n;
   }
 }
 
