@@ -12,8 +12,8 @@
 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+// 02110-1301, USA.
 
 #include "moving.h"
 
@@ -29,6 +29,8 @@
 #include "../misc/calcpaths.h"
 #include "../misc/coordinate_system.h"
 
+#include <qevent.h>
+
 #include <functional>
 #include <algorithm>
 #include <map>
