@@ -166,6 +166,7 @@ public:
 #ifdef KIG_ENABLE_PYTHON_SCRIPTING
 #include "../scripting/script-common.h"
 #include "../scripting/script_mode.h"
+#include "../scripting/python_type.h"
 
 class ScriptActionsProvider
   : public PopupActionProvider
@@ -1033,6 +1034,20 @@ void NormalModePopupObjects::setChecked( int menu, int n, bool checked )
 }
 
 #ifdef KIG_ENABLE_PYTHON_SCRIPTING
+/**
+ * this is a local function that looks for a python script associated
+ * to a clicked object
+ */
+static ObjectTypeCalcer* getPythonExecuteTypeFromCalcer( ObjectCalcer* o )
+{
+  ObjectTypeCalcer* oc = dynamic_cast<ObjectTypeCalcer *>( o );
+  if ( !oc ) return 0;
+  const PythonExecuteType* pythonexec = dynamic_cast<const PythonExecuteType*>( oc->type() );
+  if ( pythonexec ) return oc;
+
+  return 0;
+}
+
 void ScriptActionsProvider::fillUpMenu( NormalModePopupObjects& popup, int menu, int& nextfree )
 {
   if ( menu == NormalModePopupObjects::StartMenu )
@@ -1042,6 +1057,15 @@ void ScriptActionsProvider::fillUpMenu( NormalModePopupObjects& popup, int menu,
     popup.addAction( menu, p, i18n( "Python Script" ), nextfree++ );
     mns++;
   }
+  else if ( menu == NormalModePopupObjects::ToplevelMenu )
+  {
+    if ( !popup.objects().empty() &&
+         getPythonExecuteTypeFromCalcer( popup.objects().front()->calcer() ) )
+    {
+      popup.addAction( menu, i18n( "Edit Script..." ), nextfree );
+    }
+    nextfree++;
+  }
 }
 
 bool ScriptActionsProvider::executeAction(
@@ -1052,7 +1076,7 @@ bool ScriptActionsProvider::executeAction(
   {
     if ( id == 0 )
     {
-      ScriptMode m( doc );
+      ScriptCreationMode m( doc );
       m.setScriptType( ScriptType::Python );
       if ( os.size() > 0 )
       {
@@ -1068,6 +1092,24 @@ bool ScriptActionsProvider::executeAction(
       id -= mns;
     }
   }
+  else if ( menu == NormalModePopupObjects::ToplevelMenu )
+  {
+    if ( id == 0 )
+    {
+      ObjectTypeCalcer* oc = getPythonExecuteTypeFromCalcer( os.front()->calcer() );
+      if ( oc )
+      {
+        ScriptEditMode m( oc, doc );
+        m.setScriptType( ScriptType::Python );
+        doc.runMode( &m );
+      }
+      return true;
+    }
+    else
+    {
+      id -= 1;
+    }
+  }
 
   return false;
 }
