@@ -158,24 +158,23 @@ void LocusImp::getInterval( double& x1, double& x2,
                             double incr,const Coordinate& p,
                             const KigDocument& doc) const
 {
-  double epsilon = incr/1000;
-  double x3 = x1 + epsilon;
   double mm = getDist( x1, p, doc);
-  double mm1 = getDist( x3, p, doc);
+  double mm1 = getDist( x2, p, doc);
   if( mm  <= mm1 ) return;
   else
   {
-    x2 = x3;
-    while( mm > mm1 )
+    double x3 = x2 + incr;
+    double mm2 = getDist (x3, p, doc);
+    while( mm > mm1 & mm1 > mm2 )
     {
-      x3 = x2;
-      x1 += 500 * epsilon;
-      mm = getDist( x1, p, doc );
-      x2 = x1 + epsilon;
-      mm1 = getDist( x2, p, doc );
+      x1 = x2;
+      x2 = x3;
+      x3 = x2 + incr;
+      mm = mm1;
+      mm1 = mm2;
+      mm2 = getDist (x3, p, doc);
     }
-    x2=x1;
-    x1=x3;
+    x2=x3;
   }
 }
 
@@ -195,7 +194,7 @@ double LocusImp::getParam( const Coordinate& p, const KigDocument& doc ) const
   // for a local minimum from there on.  If we find one, we keep it if
   // it is the lowest of all the ones we've already found..
 
-  const int N = 60;
+  const int N = 50;
   const double incr = 1. / (double) N;
 
   // xm is the best parameter we've found so far, fxm is the distance
@@ -207,6 +206,7 @@ double LocusImp::getParam( const Coordinate& p, const KigDocument& doc ) const
   double fxm = getDist( xm, p, doc );
 
   int j = 0;
+  double mm = fxm;
 
   while( j < N )
   {
@@ -215,105 +215,127 @@ double LocusImp::getParam( const Coordinate& p, const KigDocument& doc ) const
     double x2 = x1 + incr;
 
     // check the range x1,x2 for the first local maximum..
-    getInterval( x1, x2, incr, p, doc );
-
-    // don't consider intervals where the distance is increasing..
-    if ( fabs( x1 - j * incr ) > 1.e-8 )
-    {
-      double xm1 = getParamofmin( x1, x2, p, doc);
-      double fxm1 = getDist( xm1, p, doc );
-      if( fxm1 < fxm )
-      {
-        // we found a new minimum, save it..
-        xm=xm1;
-	fxm=fxm1;
-      }
-      j = (int) ( x2 / incr );
-    }
+    double mm1 = getDist( x2, p, doc);
+    double mm2;
     j++;
+    if( mm  < mm1 ) 
+       mm = mm1;
+    
+    else
+    {
+      if ( mm > mm1 )
+      {
+        double x3 = x2 + incr;
+        mm2 = getDist (x3, p, doc);
+	j++;
+        while( mm1 > mm2 & j <= N )
+	{
+          x1 = x2;
+          x2 = x3;
+          x3 = x2 + incr;
+          mm = mm1;
+          mm1 = mm2;
+          mm2 = getDist (x3, p, doc);
+          j++;
+        }
+        x2 = x3;
+      }
+      else
+        mm2 = mm1;
+
+      if ( mm1 <= mm2 )
+      {
+        mm = mm2;
+
+        double xm1 = getParamofmin( x1, x2, p, doc);
+        double fxm1 = getDist( xm1, p, doc );
+        if( fxm1 < fxm )
+        {
+          // we found a new minimum, save it..
+          xm=xm1;
+	  fxm=fxm1;
+        }
+      }
+    }
   }
   return xm;
 }
 
 /**
- * This function calculate the parameter of the point that realize the
+ * This function calculates the parameter of the point that realizes the
  * minimum in [a,b] of the distance between the points of the locus and
- * the point of coordinate p, using the Fibonacci method.
- * This method is optimal in the sence that assigned a number of
- * iteration it reduce to minimum the interval that contain the
- * minimum of the function
+ * the point of coordinate p, using the golden ration method.
  */
 double LocusImp::getParamofmin( double a, double b,
                                 const Coordinate& p,
                                 const KigDocument& doc ) const
 {
-  double epsilon = 1.e-4;
-//  double epsilon = 1.e-8;
-  // I compute the it number of iteration of the Fibonacci method
-  // to obtain a error between the computed and the exact minimum
-  // less than epsilon
-  int it = 2;
-  int i = 1;
-  int jj = 1;
-  while( ( b - a ) / (double) ( 2 * jj ) > epsilon )
+  double epsilons = 1.e-08;
+  double epsilonl = 2.e-02;
+
+  //assert( a < b && a >= 0. && b <= 1.0);
+  assert( a < b && a >= 0.);
+
+  double r2 = ( sqrt( 5. ) - 1 ) / 2.; // golden ratio
+  double r1 = 1. - r2;
+
+  double t2 = a + r2 * ( b - a );
+  double t1 = a + r1 * ( b - a );
+  Coordinate p1 = getPoint( fmod( t1, 1. ), doc);
+  double f1 = (p1 - p).length();
+  Coordinate p2 = getPoint( fmod( t2, 1. ), doc);
+  double f2 = (p2 - p).length();
+
+  double fmin, tmin;
+  if (f1 < f2)
   {
-    int M= i + jj;
-    i= jj;
-    jj= M;
-    it++;
+    b = t2;
+    fmin = f1;
+    tmin = t1;
   }
-  int t[3];
-  t[0]= jj;
-  t[1]= i + jj;
-  t[2]= t[1] + t[0];
-
-  double x = ( b - a ) / t[2];
-  double x1 = a + t[0] * x;
-  double x2 = a + t[1] * x;
-  double fx1 = getDist( x1, p, doc) ;
-  double fx2 = getDist( x2, p, doc);
-
-  if (fx1 < fx2)
-    b = x2;
   else
-    a = x1;
-
-  for( int k=1; k <= it - 2; ++k )
   {
-    if ( fx1 < fx2 )
+    a = t1;
+    fmin = f2;
+    tmin = t2;
+  }
+
+  while ( ( b - a ) > epsilons && 
+          ( (p1 - p2).length() > 0.4 * fmin
+            || (b - a) > epsilonl) && 
+          fmin > 1.e-8 )
+  {
+    if ( f1 < f2 )
     {
-      x = x1;
-      x1 = a + x2 - x1;
-      x2 = x;
-      fx2 = fx1;
-      fx1 = getDist( x1, p, doc);
+      t2 = t1;
+      t1 = a + r1*(b - a);
+      f2 = f1;
+      p1 = getPoint( fmod( t1, 1. ), doc);
+      f1 = (p1 - p).length();
     }
     else
     {
-      x = x2;
-      x2 = b - x2 + x1;
-      x1 = x;
-      fx1 = fx2;
-      fx2 = getDist( x2, p, doc);
+      t1 = t2;
+      t2 = a + r2*(b - a);
+      f1 = f2;
+      p2 = getPoint( fmod( t2, 1. ), doc);
+      f2 = (p2 - p).length();
+    }
+    if ( f1 < f2 )
+    {
+      b = t2;
+      fmin = f1;
+      tmin = t1;
     }
-    if (fx1 < fx2 )
-      b = x2;
     else
-      a = x1;
+    {
+      a = t1;
+      fmin = f2;
+      tmin = t2;
+    }
   }
-  x1 = ( a + b ) / 2.;
-  x2 = x1 + epsilon / 2.;
-  x1 = x1 - epsilon / 2.;
-  fx1 = getDist( x1, p, doc);
-  fx2 = getDist( x2, p, doc);
-  if (fx1 < fx2)
-    b = x2;
-  else
-    a = x1;
 
-  x = fmod( ( a +b ) / 2., 1 );
-  if( x < 0 ) x += 1.;
-  return(x);
+  return(tmin);
 }
 
 void LocusImp::visit( ObjectImpVisitor* vtor ) const
