@@ -1,4 +1,3 @@
-// text_type.cc
 // Copyright (C)  2003  Dominique Devriese <devriese@kde.org>
 
 // This program is free software; you can redistribute it and/or
@@ -13,8 +12,8 @@
 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+// 02110-1301, USA.
 
 #include "text_type.h"
 
@@ -96,7 +95,12 @@ ObjectImp* TextType::calc( const Args& parents, const KigDocument& doc ) const
   return new TextImp( s, t, needframe );
 }
 
-bool TextType::canMove() const
+bool TextType::canMove( const ObjectTypeCalcer& ) const
+{
+  return true;
+}
+
+bool TextType::isFreelyTranslatable( const ObjectTypeCalcer& ) const
 {
   return true;
 }
