@@ -1,6 +1,4 @@
 /***************************************************************************
-                          klatin.cpp  -  description
-                             -------------------
     begin                : Thu Jul 17
     copyright            : (C) 2001-2004 by George Wright
     email                : gwright@kde.org
@@ -19,13 +17,14 @@
 
 #include <kapplication.h>
 #include <kconfigdialog.h>
+#include <kfiledialog.h>
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kpushbutton.h>
-#include <qradiobutton.h>
 #include <kstandarddirs.h>
+#include <kstatusbar.h>
+#include <kurlrequester.h>
 
-#include <pwd.h>
 #include <unistd.h>
 #include <stdlib.h>
 #include <sys/types.h>
@@ -37,7 +36,7 @@ KLatin::KLatin(QWidget* parent, const char *name)
 	: KMainWindow(parent, name)
 {
 	m_section = 0;
-
+	
 	// Setup the actions for the menubar
 	setupActions();
 
@@ -55,52 +54,23 @@ void KLatin::setupActions()
 {
 	// Setup various menu actions
 	KStdAction::preferences(this, SLOT(loadSettings()), actionCollection());
-	m_loadVocab = new KAction(i18n("Load &Vocabulary"), 0, this, SLOT(menuVocab()),  actionCollection(), "go_vocab");
-	m_loadGrammar = new KAction(i18n("Load &Grammar"), 0, this, SLOT(menuGrammar()),  actionCollection(), "go_grammar");
-	m_loadVerbs = new KAction(i18n("Load V&erbs"), 0, this, SLOT(menuVerbs()),  actionCollection(), "go_verbs");
-	m_loadRevision = new KAction(i18n("Load &Revision"), 0, this, SLOT(menuRevision()),  actionCollection(), "go_revision");
-	m_changeFile = new KAction(i18n("&Load Vocabulary File"), 0, this, SLOT(menuChangeVocab()),  actionCollection(), "load_file");
+	m_loadVocab = new KAction(i18n("Load &Vocabulary"), 0, this, SLOT(loadVocab()),  actionCollection(), "go_vocab");
+	m_loadGrammar = new KAction(i18n("Load &Grammar"), 0, this, SLOT(loadGrammar()),  actionCollection(), "go_grammar");
+	m_loadVerbs = new KAction(i18n("Load V&erbs"), 0, this, SLOT(loadVerbs()),  actionCollection(), "go_verbs");
+	m_loadRevision = new KAction(i18n("Load &Revision"), 0, this, SLOT(loadRevision()),  actionCollection(), "go_revision");
 	KStdAction::quit(kapp, SLOT(quit()), actionCollection());
-	m_changeFile->setEnabled(FALSE);
 }
 
 void KLatin::startClicked()
 {
 	if (klatinchoose->VocabOption->isOn())
-		loadSection(1);
+		loadVocab();
 	if (klatinchoose->GrammarOption->isOn())
-		loadSection(2);
+		loadGrammar();
 	if (klatinchoose->VerbsOption->isOn())
-		loadSection(3);
+		loadVerbs();
 	if (klatinchoose->RevisionOption->isOn())
-		loadSection(4);
-}
-
-void KLatin::loadSection(int option)
-{
-	// option is an integer passed to the function
-	// stating which radio button was checked when
-	// start was clicked.
-	//
-	// 1 = vocab, 2 = grammar, 3 = verbs and
-	// 4 = revision
-	switch (option) {
-		case 1:
-			klatinchoose->close();
-			loadVocab();
-			break;
-		case 2:
-			klatinchoose->close();
-			loadGrammar();
-			break;
-		case 3:
-			klatinchoose->close();
-			loadVerbs();
-			break;
-		case 4:
-			loadRevision();
-			break;
-		}
+		loadRevision();
 }
 
 // Start of section loading code
@@ -112,12 +82,13 @@ void KLatin::loadVocab()
 	klatinvocabsection = new KLatinVocab(this);
 	klatinvocabsection->show();
 
+	slotWriteMsg(i18n("Ready"));
+
 	// Set this widget as the central widget
 	setCentralWidget(klatinvocabsection);
 
 	updateSection(FALSE);
 	
-	m_changeFile->setEnabled(TRUE);
 	// When the child emits the signal exitted(),
 	// then reset the GUI to go back to the menu
 	connect(klatinvocabsection, SIGNAL(exited()), this, SLOT(resetGUI()));
@@ -133,6 +104,8 @@ void KLatin::loadGrammar()
 	klatingrammarsection = new KLatinGrammar(this);
 	klatingrammarsection->show();
 
+	slotWriteMsg(i18n("Grammar"));
+
 	// Disable all the menu entries under Section/
 	updateSection(FALSE);
 	
@@ -142,11 +115,16 @@ void KLatin::loadGrammar()
 	// When the child emits the signal exited(),
 	// then reset the GUI to go back to the menu
 	connect(klatingrammarsection, SIGNAL(exited()), this, SLOT(resetGUI()));
-
+	connect(klatingrammarsection, SIGNAL(statusMsg(const QString&)), this, SLOT(slotWriteMsg(const QString&)));
 	// Set the section variable
 	m_section = 2;
 }
 
+void KLatin::slotWriteMsg(const QString& message)
+{
+	statusBar()->message(message);
+}
+
 void KLatin::loadVerbs()
 {
 	klatinchoose->close();
@@ -154,17 +132,18 @@ void KLatin::loadVerbs()
 	klatinverbssection = new KLatinVerbs(this);
 	klatinverbssection->show();
 
+	slotWriteMsg(i18n("Verbs"));
+
 	// Disable all the menu entries under Section/
 	updateSection(FALSE);
 
-	klatinverbssection->ChangeButton->setIconSet(KGlobal::iconLoader()->loadIconSet("apply", KIcon::Small));
-	
 	// Set this widget as the central widget
 	setCentralWidget(klatinverbssection);
 
 	// When the child emits the signal exited(),
 	// then reset the GUI to go back to the menu
 	connect(klatinverbssection, SIGNAL(exited()), this, SLOT(resetGUI()));
+	connect(klatinverbssection, SIGNAL(statusMsg(const QString&)), this, SLOT(slotWriteMsg(const QString&)));
 
 	// Set the section variable
 	m_section = 3;
@@ -172,7 +151,7 @@ void KLatin::loadVerbs()
 
 void KLatin::loadRevision()
 {
-	kapp->invokeHelp("klatin-index");
+	kapp->invokeHelp("klatin-index", "klatin");
 }
 
 void KLatin::loadSettings()
@@ -183,6 +162,9 @@ void KLatin::loadSettings()
 	KConfigDialog *dialog = new KConfigDialog(this, "settings", Settings::self());
 	
 	vocabPage = new VocabPage(0); 
+	vocabPage->kcfg_DefaultFile->setMode(KFile::File | KFile::LocalOnly);
+	vocabPage->kcfg_DefaultFile->setFilter("*.kvtml");
+	vocabPage->kcfg_DefaultFile->setCaption(i18n("Load Vocabulary File"));
 	dialog->addPage(vocabPage, i18n("Vocabulary"), "kdict"); 
 	connect(dialog, SIGNAL(settingsChanged()), this, SLOT(settingsChanged())); 
 	dialog->show();
@@ -202,6 +184,7 @@ void KLatin::resetGUI()
 	// various options that are available to choose
 	// and setCentralWidget it.
 	klatinchoose = new KLatinChoose(this);
+	klatinchoose->QuitButton->setIconSet(KGlobal::iconLoader()->loadIconSet("exit", KIcon::Small));
 	klatinchoose->show();
 	setCentralWidget(klatinchoose);
 
@@ -209,8 +192,7 @@ void KLatin::resetGUI()
 	connect(klatinchoose->StartButton, SIGNAL(clicked()), this, SLOT(startClicked()));
 	// Make the quit button quit the application :)
 	connect(klatinchoose->QuitButton, SIGNAL(clicked()), kapp, SLOT(quit()));
-
-	m_changeFile->setEnabled(false);
+	
 	// Enable all the menu entries under Section/
 	updateSection(TRUE);
 
@@ -219,39 +201,8 @@ void KLatin::resetGUI()
 
 	// Reset the section variable
 	m_section = 0;
-}
 
-void KLatin::menuVocab()
-{
-	// Get rid of the opening widget
-	klatinchoose->close();
-
-	// Load the vocabulary stuff
-	loadVocab();
-}
-
-void KLatin::menuGrammar()
-{
-	// Get rid of the opening widget
-	klatinchoose->close();
-
-	// Load the grammar stuff
-	loadGrammar();
-}
-
-void KLatin::menuVerbs()
-{
-	// Get rid of the opening widget
-	klatinchoose->close();
-
-	// Load the verbs stuff
-	loadVerbs();
-}
-
-void KLatin::menuRevision()
-{
-	// Load the revision stuff
-	loadRevision();
+	slotWriteMsg(i18n("Ready"));
 }
 
 void KLatin::updateSection(bool m_bool)
@@ -263,25 +214,4 @@ void KLatin::updateSection(bool m_bool)
 	m_loadRevision->setEnabled(m_bool);
 }
 
-void KLatin::menuChangeVocab()
-{
-	QString vocabdir = "klatin/data/vocabs/";
-	vocabdir += Settings::userLanguage();
-	vocabdir += "/";
-	
-	// Load a file dialogue to choose a different vocabulary file
-	loadVocabDialog = new KFileDialog(locate("data", vocabdir), "*.kvtml", 0, 0, TRUE);
-	loadVocabDialog->show();
-	
-	connect(loadVocabDialog, SIGNAL(okClicked()), this, SLOT(menuChangeConfirm()));
-}
-
-void KLatin::menuChangeConfirm()
-{
-	// This slot is called when OK is pressed on the file dialogue
-	klatinvocabsection->changeVocab(loadVocabDialog->selectedFile());
-	Settings::setDefaultFile(loadVocabDialog->selectedFile());
-	Settings::writeConfig();
-}
-
 #include "klatin.moc"
