@@ -151,17 +151,19 @@ void KLettres::findLanguages()
 
 QString Prefs::defaultLanguage()
 {
-    //see what is the user language for KDE
-    QStringList defaultLanguages = KGlobal::locale()->languagesTwoAlpha();
-    if (!defaultLanguages.isEmpty()) {
-        //scan to see if defaultLanguages[0] belongs to m_languages. If not, en is default.
-        int i = Prefs::self()->m_languages.findIndex(defaultLanguages[0]);
-        if (i<1)
-            return "en";
-        else
-            return defaultLanguages[0];
-    }
-    return QString::null;
+	//see what is the user language for KDE
+	QStringList defaultLanguages = KGlobal::locale()->languagesTwoAlpha();
+	if (!defaultLanguages.isEmpty()) {
+	//scan to see if defaultLanguages[0] belongs to m_languages. If not, en is default.
+	int i = Prefs::self()->m_languages.findIndex(defaultLanguages[0]);
+		if (Prefs::self()->m_languages.contains(Prefs::language()))
+			return Prefs::language(); //the last language played
+		else if (i<1)
+			return "en"; //if no other
+		else
+			return Prefs::self()->m_languages[i]; //KDE default if exists
+	}
+	return QString::null;
 }
 
 
@@ -447,7 +449,7 @@ void KLettres::slotModeKid()
 void KLettres::loadLangToolBar()
 {
     m_secondToolbar->clear();
-    if (m_languages[Prefs::languageNumber()]== "cs" || m_languages[Prefs::languageNumber()]== "da" || m_languages[Prefs::languageNumber()]== "sk" || m_languages[Prefs::languageNumber()]== "es" || m_languages[Prefs::languageNumber()]== "de")//Dutch, English, French and Italian have no special characters
+    if (m_languages[Prefs::languageNumber()]== "cs" || m_languages[Prefs::languageNumber()]== "da" || m_languages[Prefs::languageNumber()]== "sk" || m_languages[Prefs::languageNumber()]== "es" || m_languages[Prefs::languageNumber()]== "de" || m_languages[Prefs::languageNumber()]== "nds")//Dutch, English, French and Italian have no special characters
     {
         allData.clear();
         QString myString=QString("klettres/%1.txt").arg(m_languages[Prefs::languageNumber()]);
