@@ -1,7 +1,7 @@
 /*
 * KmPlot - a math. function plotter for the KDE-Desktop
 *
-* Copyright (C) 1998, 1999  Klaus-Dieter Mller
+* Copyright (C) 1998, 1999  Klaus-Dieter Möller
 *               2000, 2002 kd.moeller@t-online.de
 *               
 * This file is part of the KDE Project.
@@ -19,7 +19,7 @@
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
-* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */
 
@@ -42,24 +42,28 @@ KPrinterDlg::KPrinterDlg( QWidget *parent, const char *name )
 	layout->setSpacing( KDialog::spacingHint() );
 
 
-	m_printtable = new QCheckBox( i18n( "Print header table" ), this );
-	m_printtable->setChecked( true );
-	layout->addWidget( m_printtable );
+	printHeaderTable = new QCheckBox( i18n( "Print header table" ), this );
+	transparent_background = new QCheckBox( i18n( "Transparent background" ), this );
+	layout->addWidget( printHeaderTable );
+	layout->addWidget( transparent_background );
 	layout->addStretch( 1 );
 }
 
 void KPrinterDlg::getOptions( QMap<QString, QString>& opts, bool include_def )
 {
-	if ( include_def || !m_printtable->isChecked() )
-		opts[ "app-kmplot-printtable" ] = ( m_printtable->isChecked() ? "1" : "-1" );
+ 	if ( include_def || !printHeaderTable->isChecked() )
+ 		opts[ "app-kmplot-printtable" ] = ( printHeaderTable->isChecked() ? "1" : "-1" );
+	if ( include_def || !transparent_background->isChecked() )
+		opts[ "app-kmplot-printbackground" ] = ( transparent_background->isChecked() ? "1" : "-1" );
 }
 
 void KPrinterDlg::setOptions( const QMap<QString, QString>& opts )
 {
-	m_printtable->setChecked( opts[ "app-kmplot-printtable" ] != "-1" );
+	printHeaderTable->setChecked( opts[ "app-kmplot-printtable" ] != "-1" );
+	transparent_background->setChecked( opts[ "app-kmplot-printbackground" ] != "-1" );
 }
 
-bool KPrinterDlg::isValid( QString& msg )
+bool KPrinterDlg::isValid( const QString& )
 {
 	return true;
 }
