@@ -177,7 +177,7 @@ KPercentMain::KPercentMain( QWidget *parent, const char *name ) :
 
 	QToolTip::add( progress_bar_count, i18n( "Number of managed exercises" ) );
 	QToolTip::add( progress_bar_right_wrong, i18n( "Relation of right to wrong inputs" ) );
-	QToolTip::add( push_button_apply, i18n( "Apply your input" ) );
+	QToolTip::add( push_button_apply, i18n( "Check your answer" ) );
 	QToolTip::add( push_button_cancel, i18n( "Back to the main window" ) );
 
     // signals and slots connections
