@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU Lesser General Public
     License along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #endif
 
@@ -65,20 +65,20 @@ static INumber eq[] = {
 };
 //TODO decide appropiate TIME_OUT
 static INumberVectorProperty eqNum = {
-    mydev, "EQUATORIAL_COORD", "Equatorial J2000", BASIC_GROUP, IP_RW, 0, IPS_IDLE,
-    eq, NARRAY(eq), 0, 0};
+    mydev, "EQUATORIAL_EOD_COORD", "Equatorial JNow", BASIC_GROUP, IP_RW, 0, IPS_IDLE,
+    eq, NARRAY(eq), "", 0};
 
 /* Fundamental group */
-static ISwitchVectorProperty PowerSw	= { mydev, "CONNECTION" , "Connection", COMM_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, PowerS, NARRAY(PowerS), 0, 0};
+static ISwitchVectorProperty PowerSw	= { mydev, "CONNECTION" , "Connection", COMM_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, PowerS, NARRAY(PowerS), "", 0};
 static IText PortT[]			= {{"PORT", "Port", 0, 0, 0, 0}};
-static ITextVectorProperty Port		= { mydev, "DEVICE_PORT", "Ports", COMM_GROUP, IP_RW, 0, IPS_IDLE, PortT, NARRAY(PortT), 0, 0};
+static ITextVectorProperty Port		= { mydev, "DEVICE_PORT", "Ports", COMM_GROUP, IP_RW, 0, IPS_IDLE, PortT, NARRAY(PortT), "", 0};
 
 /* Movement group */
-static ISwitchVectorProperty OnCoordSetSw    = { mydev, "ON_COORD_SET", "On Set", BASIC_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, OnCoordSetS, NARRAY(OnCoordSetS), 0, 0};
-static ISwitchVectorProperty abortSlewSw     = { mydev, "ABORT_MOTION", "Abort Slew/Track", BASIC_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, abortSlewS, NARRAY(abortSlewS), 0, 0};
-static ISwitchVectorProperty SlewModeSw      = { mydev, "Slew rate", "", MOVE_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, SlewModeS, NARRAY(SlewModeS), 0, 0};
+static ISwitchVectorProperty OnCoordSetSw    = { mydev, "ON_COORD_SET", "On Set", BASIC_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, OnCoordSetS, NARRAY(OnCoordSetS), "", 0};
+static ISwitchVectorProperty abortSlewSw     = { mydev, "ABORT_MOTION", "Abort Slew/Track", BASIC_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, abortSlewS, NARRAY(abortSlewS), "", 0};
+static ISwitchVectorProperty SlewModeSw      = { mydev, "Slew rate", "", MOVE_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, SlewModeS, NARRAY(SlewModeS), "", 0};
 
-static ISwitchVectorProperty MovementSw      = { mydev, "MOVEMENT", "Move toward", MOVE_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, MovementS, NARRAY(MovementS), 0, 0};
+static ISwitchVectorProperty MovementSw      = { mydev, "MOVEMENT", "Move toward", MOVE_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, MovementS, NARRAY(MovementS), "", 0};
 
 
 /* send client definitions of all properties */
@@ -107,6 +107,8 @@ void ISNewText (const char *dev, const char *name, char *texts[], char *names[],
 void ISNewNumber (const char *dev, const char *name, double values[], char *names[], int n)
 { ISInit(); telescope->ISNewNumber(dev, name, values, names, n);}
 void ISPoll (void *p) { telescope->ISPoll(); IEAddTimer (POLLMS, ISPoll, NULL); p=p;}
+void ISNewBLOB (const char */*dev*/, const char */*name*/, int */*sizes[]*/, char **/*blobs[]*/, char **/*formats[]*/, char **/*names[]*/, int /*n*/)
+{}
 
 /**************************************************
 *** LX200 Generic Implementation
@@ -206,7 +208,8 @@ int CelestronGPS::handleCoordSet()
 	  eqNum.s = IPS_BUSY;
 	  fs_sexa(RAStr, targetRA, 2, 3600);
 	  fs_sexa(DecStr, targetDEC, 2, 3600);
-	  IDSetNumber(&eqNum, "Slewing to J2000 RA %s - DEC %s", RAStr, DecStr);
+	  IDSetNumber(&eqNum, "Slewing to JNOW RA %s - DEC %s", RAStr, DecStr);
+	  IDLog("Slewing to JNOW RA %s - DEC %s", RAStr, DecStr);
 	  break;
 
 
@@ -236,7 +239,8 @@ int CelestronGPS::handleCoordSet()
 		fs_sexa(RAStr, targetRA, 2, 3600);
 	        fs_sexa(DecStr, targetDEC, 2, 3600);
 		eqNum.s = IPS_BUSY;
-		IDSetNumber(&eqNum, "Slewing to J2000 RA %s - DEC %s", RAStr, DecStr);
+		IDSetNumber(&eqNum, "Slewing to JNow RA %s - DEC %s", RAStr, DecStr);
+		IDLog("Slewing to JNOW RA %s - DEC %s", RAStr, DecStr);
 	  }
 	  else
 	  {
@@ -311,9 +315,9 @@ void CelestronGPS::ISNewNumber (const char *dev, const char *name, double values
 	   // update JD
            JD = UTtoJD(tp);
 
-	   IDLog("We recevined J2000 RA %f - DEC %f\n", newRA, newDEC);;
-	   apparentCoord( (double) J2000, JD, &newRA, &newDEC);
-	   IDLog("Processed to RA %f - DEC %f\n", newRA, newDEC);
+	   IDLog("We recevined JNOW RA %f - DEC %f\n", newRA, newDEC);;
+	   /*apparentCoord( (double) J2000, JD, &newRA, &newDEC);
+	   IDLog("Processed to RA %f - DEC %f\n", newRA, newDEC);*/
 
 	       //eqNum.np[0].value = values[0];
 	       //eqNum.np[1].value = values[1];
@@ -357,7 +361,7 @@ void CelestronGPS::ISNewSwitch (const char *dev, const char *name, ISState *stat
 	// Suppress warning
 	names = names;
 
-	IDLog("in new Switch with Device= %s and Property= %s and #%d items\n", dev, name,n);
+	//IDLog("in new Switch with Device= %s and Property= %s and #%d items\n", dev, name,n);
 	//IDLog("SolarSw name is %s\n", SolarSw.name);
 
 	// ignore if not ours //
@@ -497,8 +501,8 @@ void CelestronGPS::ISNewSwitch (const char *dev, const char *name, ISState *stat
 	      return;
 	   }
 	      
-          IDLog("We have switch %d \n ", index);
-	  IDLog("NORTH: %d -- WEST: %d -- EAST: %d -- SOUTH %d\n", lastMove[0], lastMove[1], lastMove[2], lastMove[3]);
+          //IDLog("We have switch %d \n ", index);
+	  //IDLog("NORTH: %d -- WEST: %d -- EAST: %d -- SOUTH %d\n", lastMove[0], lastMove[1], lastMove[2], lastMove[3]);
 
 	  if (lastMove[index] == 1)
 	    StartSlew(index);
@@ -633,7 +637,7 @@ void CelestronGPS::ISPoll()
 		currentRA = targetRA;
 		currentDEC = targetDEC;
 
-		apparentCoord( JD, (double) J2000, &currentRA, &currentDEC);
+		/*apparentCoord( JD, (double) J2000, &currentRA, &currentDEC);*/
 
 		eqNum.np[0].value = currentRA;
 		eqNum.np[1].value = currentDEC;
@@ -689,7 +693,7 @@ void CelestronGPS::ISPoll()
 	     currentRA = GetRA();
 	     currentDEC = GetDec();
 
-	     apparentCoord( JD, (double) J2000, &currentRA, &currentDEC);
+	     /*apparentCoord( JD, (double) J2000, &currentRA, &currentDEC);*/
 
 
 	     eqNum.np[0].value = currentRA;
