@@ -38,6 +38,8 @@
 #include <qcheckbox.h>
 #include <qdir.h>
 #include <kdeversion.h>
+//FIXME GLSOSSARY (uncomment these when content is added)
+//#include <libkdeedu/kdeeduui/kdeeduglossary.h>
 
 #include "opscatalog.h"
 #include "opsguides.h"
@@ -77,6 +79,7 @@
 #include "indidriver.h"
 #include "indifitsconf.h"
 #include "telescopewizardprocess.h"
+#include "telescopeprop.h"
 #include "fitsviewer.h"
 
 #if ( KDE_IS_VERSION( 3, 2, 90 ) )
@@ -153,7 +156,13 @@ void KStars::slotWizard() {
 
 		// If the sky is in Horizontal mode and not tracking, reset focus such that
 		// Alt/Az remain constant.
-		if ( ! Options::isTracking() && Options::useAltAz() ) {
+		if ( data()->useDefaultOptions ) {
+			SkyPoint newPoint;
+			newPoint.setAz( Options::focusRA() );
+			newPoint.setAlt( Options::focusDec() + 0.0001 );
+			newPoint.HorizontalToEquatorial( LST(), geo()->lat() );
+			map()->setDestination( &newPoint );
+		} else if ( ! Options::isTracking() && Options::useAltAz() ) {
 			map()->focus()->HorizontalToEquatorial( LST(), geo()->lat() );
 		}
 
@@ -187,6 +196,17 @@ void KStars::slotWUT() {
 	dialog.exec();
 }
 
+//FIXME GLOSSARY
+// void KStars::slotGlossary(){
+// 	GlossaryDialog *dlg = new GlossaryDialog( true, this, "glossary" );
+// 	QString glossaryfile =data()->stdDirs->findResource( "data", "kstars/glossary.xml" );
+// 	KURL u = glossaryfile;
+// 	Glossary *g = Glossary::readFromXML( u );
+// 	g->setName( i18n( "Knowledge" ) );
+// 	dlg->addGlossary( g );
+// 	dlg->show();
+// }
+
 void KStars::slotScriptBuilder() {
 	ScriptBuilder sb(this);
 	sb.exec();
@@ -217,6 +237,12 @@ void KStars::slotTelescopeWizard()
   twiz.exec();
 }
 
+void KStars::slotTelescopeProperties()
+{
+  telescopeProp scopeProp(this);
+  scopeProp.exec();
+}
+
 void KStars::slotINDIPanel() {
 
    if (indimenu == NULL)
@@ -233,8 +259,12 @@ void KStars::slotINDIDriver() {
 
 void KStars::slotINDIConf() {
 
-   INDIFITSConf indiconf(this);
+   INDIFITSConf indioptions(this);
 
+    indioptions.loadOptions();
+   /*QStringList filterList;
+ 
+   
    indiconf.timeCheck->setChecked( Options::indiAutoTime() );
    indiconf.GeoCheck->setChecked( Options::indiAutoGeo() );
    indiconf.crosshairCheck->setChecked( Options::indiCrosshairs() );
@@ -251,16 +281,24 @@ void KStars::slotINDIConf() {
    else
    indiconf.fitsDIR_IN->setText ( Options::fitsSaveDirectory());
 
-   if (indiconf.exec() == QDialog::Accepted)
+   if (Options::filterAlias().empty())
    {
-     Options::setIndiAutoTime( indiconf.timeCheck->isChecked() );
+        filterList << "0" << "1" << "2" << "3" << "4" << "5" << "6" << "7" << "8"
+                   << "9";
+        indiconf.filterCombo->insertStringList(filterList);
+   }*/
+
+   if (indioptions.exec() == QDialog::Accepted)
+   {
+     /*Options::setIndiAutoTime( indiconf.timeCheck->isChecked() );
      Options::setIndiAutoGeo( indiconf.GeoCheck->isChecked() );
      Options::setIndiCrosshairs( indiconf.crosshairCheck->isChecked() );
      Options::setIndiMessages( indiconf.messagesCheck->isChecked() );
      Options::setIndiFITSDisplay (indiconf.fitsAutoDisplayCheck->isChecked());
      Options::setIndiTelescopePort ( indiconf.telPort_IN->text());
      Options::setIndiVideoPort( indiconf.vidPort_IN->text());
-     Options::setFitsSaveDirectory( indiconf.fitsDIR_IN->text());
+     Options::setFitsSaveDirectory( indiconf.fitsDIR_IN->text());*/
+     indioptions.saveOptions();
 
      map()->forceUpdateNow();
    }
@@ -327,17 +365,18 @@ void KStars::slotViewOps() {
 	OpsColors  *opcolors     = new OpsColors( this, "colors" );
 	OpsAdvanced *opadvanced  = new OpsAdvanced( this, "advanced" );
 
-	dialog->addPage( opcatalog,  i18n("Catalogs"), stdDirs.findResource( "data", "kstars/opscatalog.png" ) );
-	dialog->addPage( opsolsys,   i18n("Solar System"), stdDirs.findResource( "data", "kstars/opssolarsystem.png" ) );
-	dialog->addPage( opguides,   i18n("Guides"), stdDirs.findResource( "data", "kstars/opsguides.png" ) );
-	dialog->addPage( opcolors,   i18n("Colors"), stdDirs.findResource( "data", "kstars/opscolors.png" ) );
-	dialog->addPage( opadvanced, i18n("Advanced"), stdDirs.findResource( "data", "kstars/opsadvanced.png" ) );
+	dialog->addPage(opcatalog, i18n("Catalogs"), "kstars_catalog");
+	dialog->addPage(opsolsys, i18n("Solar System"), "kstars_solarsystem");
+	dialog->addPage(opguides, i18n("Guides"), "kstars_guides");
+	dialog->addPage(opcolors, i18n("Colors"), "kstars_colors");
+	dialog->addPage(opadvanced, i18n("Advanced"), "kstars_advanced");
 
 	dialog->show();
 }
 
-void KStars::slotApplySettings() {
+void KStars::slotApplyConfigChanges() {
 	Options::writeConfig();
+	applyConfig();
 	data()->setFullTimeUpdate();
 	map()->forceUpdate();
 }
@@ -447,7 +486,7 @@ void KStars::slotRunScript() {
 
 				while ( ! saveURL.isValid() ) {
 					message = i18n( "Save location is invalid. Try another location?" );
-					if ( KMessageBox::warningYesNo( 0, message, i18n( "Invalid Save Location" ) ) == KMessageBox::No ) return;
+					if ( KMessageBox::warningYesNo( 0, message, i18n( "Invalid Save Location" ), i18n("Try Another"), i18n("Do Not Try") ) == KMessageBox::No ) return;
 					saveURL = KFileDialog::getSaveURL( QDir::homeDirPath(), "*.kstars|KStars Scripts (*.kstars)" );
 				}
 
@@ -513,16 +552,24 @@ void KStars::slotRunScript() {
 		}
 
 		if ( ! fileOK ) {
-			KMessageBox::sorry( 0, i18n( "The selected file appears to be an invalid KStars script." ),
-					i18n( "Script Validation Failed" ) );
-		} else {
-			//file is OK, run it!
-			KProcess p;
-			p << f.name();
-			p.start( KProcess::DontCare );
-
-			while ( p.isRunning() ) kapp->processEvents( 50 ); //otherwise tempfile may get deleted before script completes.
+			int answer;
+			answer = KMessageBox::warningContinueCancel( 0, i18n( "The selected script contains unrecognized elements,"
+				"indicating that it was not created using the KStars script builder. "
+				"This script may not function properly, and it may even contain malicious code. "
+				"Would you like to execute it anyway?" ),
+					i18n( "Script Validation Failed" ), i18n("Run Nevertheless"), "daExecuteScript" );
+			if ( answer == KMessageBox::Cancel ) return;
 		}
+
+		//FIXME STRINGS FREEZE
+		//Add statusbar message that script is running
+		//ks->statusBar()->changeItem( i18n( "Running script: %1" ).arg( fileURL.fileName() ), 0 );
+
+		KProcess p;
+		p << f.name();
+		p.start( KProcess::DontCare );
+
+		while ( p.isRunning() ) kapp->processEvents( 50 ); //otherwise tempfile may get deleted before script completes.
 	}
 }
 
@@ -537,7 +584,7 @@ void KStars::slotPrint() {
 
 		int answer;
 		answer = KMessageBox::questionYesNoCancel( 0, message, i18n( "Switch to Star Chart Colors?" ),
-			KStdGuiItem::yes(), KStdGuiItem::no(), "askAgainPrintColors" );
+			i18n("Switch Color Scheme"), i18n("Do Not Switch"), "askAgainPrintColors" );
 
 		if ( answer == KMessageBox::Cancel ) return;
 		if ( answer == KMessageBox::Yes ) switchColors = true;
@@ -742,9 +789,22 @@ void KStars::slotSetZoom() {
 void KStars::slotCoordSys() {
 	if ( Options::useAltAz() ) {
 		Options::setUseAltAz( false );
+		if ( Options::useRefraction() ) {
+			if ( map()->focusObject() ) //simply update focus to focusObject's position
+				map()->setFocus( map()->focusObject() );
+			else { //need to recompute focus for unrefracted position
+				map()->setFocusAltAz( map()->refract( map()->focus()->alt(), false ).Degrees(), 
+						map()->focus()->az()->Degrees() );
+				map()->focus()->HorizontalToEquatorial( data()->lst(), geo()->lat() );
+			}
+		}
 		actCoordSys->turnOn();
 	} else {
 		Options::setUseAltAz( true );
+		if ( Options::useRefraction() ) {
+			map()->setFocusAltAz( map()->refract( map()->focus()->alt(), true ).Degrees(), 
+					map()->focus()->az()->Degrees() );
+		}
 		actCoordSys->turnOff();
 	}
 	map()->forceUpdate();
@@ -795,7 +855,7 @@ void KStars::slotFOVEdit() {
 				QTextStream ostream(&f);
 
 				for ( FOV *fov = fovdlg.FOVList.first(); fov; fov = fovdlg.FOVList.next() )
-					ostream << fov->name() << ":" << KGlobal::locale()->formatNumber( fov->size() )
+					ostream << fov->name() << ":" << fov->size()
 							<< ":" << QString("%1").arg( fov->shape() ) << ":" << fov->color() << endl;
 
 				f.close();
