@@ -1133,6 +1133,11 @@ bool KStarsData::addCatalog( QString filename ) {
 			ObjNames.append( o );
 			if ( o->hasLongName() && o->longname() != o->name() ) 
 				ObjNames.append( o, true ); //Add long name
+			// PdV
+			//if (reloadMode) {
+		        //        o->EquatorialToHorizontal( LST, geo()->lat() );
+			//}
+
 		}
 
 		return true;
@@ -2146,11 +2151,12 @@ void KStarsData::updateTime( GeoLocation *geo, SkyMap *skymap, const bool automa
 			}
 		}
 
+
 		//Custom Catalogs
 		for ( unsigned int j=0; j< CustomCatalogs.count(); ++j ) {
-			CustomCatalog *cat = CustomCatalogs.at(j);
+			QPtrList<SkyObject> cat = CustomCatalogs.at(j)->objList();
 			if ( Options::showCatalog()[j] ) {
-				for ( SkyObject *o = cat->objList().first(); o; o = cat->objList().next() ) {
+                                 for ( SkyObject *o = cat.first(); o; o = cat.next() ) {
 					if (needNewCoords) o->updateCoords( &num );
 					o->EquatorialToHorizontal( LST, geo->lat() );
 				}
@@ -2309,6 +2315,20 @@ SkyObject* KStarsData::objectNamed( const QString &name ) {
 		if ( name==cnameList.at(i)->name() ) return cnameList.at(i);
 	}
 
+	//Still no match.  Try interpreting the string as a genetive star name 
+	//(with ascii characters instead of a Greek letter)
+	for ( unsigned int i=0; i<starList.count(); ++i ) {
+		if ( name==starList.at(i)->gname( false ) ) return starList.at(i);
+	}
+
+       //Custom catalogs. 
+        for ( unsigned int i=0; i<CustomCatalogs.count(); ++i ) {
+                QPtrList<SkyObject> custCatObjs = CustomCatalogs.at(i)->objList();
+                for ( unsigned int j = 0; j < custCatObjs.count(); ++j ) {
+                        if ( name==custCatObjs.at(j)->name() ) return custCatObjs.at(j);
+                }
+        }
+
 	//reach here only if argument is not matched
 	return NULL;
 }
