@@ -1,8 +1,8 @@
 /***************************************************************************
- *   ktouchstatistics.cpp                                                  *
- *   --------------------                                                  *
- *   Copyright (C) 2000 by Hvard Friland, 2003 by Andreas Nicolai        *
- *   haavard@users.sourceforge.net                                         *
+ *   ktouchchartwidget.h                                                   *
+ *   -------------------                                                   *
+ *   Copyright (C) 2000 by Håvard Frøiland, 2004 by Andreas Nicolai        *
+ *   ghorwin@users.sourceforge.net                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -13,37 +13,22 @@
 #ifndef KTOUCHCHARTWIDGET
 #define KTOUCHCHARTWIDGET
 
-#include <qframe.h>
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
-class QResizeEvent;
-class QPaintEvent;
+#include <libkdeedu/kdeeduplot/kplotwidget.h>
 
 class KTouchTrainer;
 
 /// This is the chart widget and contains all chart drawing code.
-class KTouchChartWidget : public QFrame {
+class KTouchChartWidget : public KPlotWidget {
     Q_OBJECT
   public:
-    enum chart_t {
-        CharsPerMinute,
-        WordsPerMinute,
-        Accuracy,
-        ElapsedTime
-    };
     /// Constructor.
     KTouchChartWidget(QWidget* parent, const char *name=0);
     /// Destructor.
     ~KTouchChartWidget();
-    /// Sets the chart type and triggers an update.
-    void setChartType(chart_t type);
-
-    KTouchTrainer  *m_trainer;      ///< Pointer to the trainer object
-
-  protected:
-    void paintEvent(QPaintEvent *pe);
-
-  private:
-    chart_t         m_chartType;    ///< Type of chart to draw
 };
 
 #endif  // KTOUCHCHARTWIDGET
