@@ -14,6 +14,7 @@
 #include "ktouchkeyboardwidget.moc"
 
 #include <algorithm>
+#include <set>
 
 #include <qfile.h>
 
@@ -25,15 +26,18 @@
 #include <kmessagebox.h>
 
 #include "prefs.h"
+#include "ktouchkeyconnector.h"
 
 // the margin between keyboard and widget frame
 const int MARGIN = 10;
 
+QMap<QChar, int>	 			KTouchKeyboardWidget::m_keyCharMap;
 // --------------------------------------------------------------------------
 
 
 KTouchKeyboardWidget::KTouchKeyboardWidget(QWidget *parent)
-  : QWidget(parent), m_keyboardWidth(100), m_keyboardHeight(60), m_currentLayout("")
+  : QWidget(parent), m_keyboardWidth(100), m_keyboardHeight(60), m_currentLayout(""),
+	m_hideKeyboard(false)
 {
     setMinimumHeight(100);          // when it's smaller you won't see anything
     m_keyList.setAutoDelete(true);  // the list is responsable for cleaning up
@@ -103,6 +107,11 @@ void KTouchKeyboardWidget::saveKeyboard(QWidget * window, const KURL& url) {
 }
 
 void KTouchKeyboardWidget::applyPreferences(QWidget * window, bool silent) {
+	m_hideKeyboard = Prefs::hideKeyboard();
+	if (m_hideKeyboard) 
+    	setMaximumHeight(100);
+	else
+    	setMaximumHeight(10000);
     // let's check whether the keyboard layout has changed
     if (Prefs::currentKeyboardFile() != m_currentLayout) {
         // if the layout is the number layout just create it and we're done
@@ -147,6 +156,7 @@ void KTouchKeyboardWidget::applyPreferences(QWidget * window, bool silent) {
 
 
 void KTouchKeyboardWidget::newKey(const QChar& nextChar) {
+	if (m_hideKeyboard) return;
     QPainter painter(this);
     painter.translate(m_shift, MARGIN);
     // first clean the markings on all keys
@@ -182,13 +192,49 @@ void KTouchKeyboardWidget::newKey(const QChar& nextChar) {
 
 
 void KTouchKeyboardWidget::paintEvent(QPaintEvent *) {
-    QPainter painter(this);
-    painter.translate(m_shift, MARGIN);
+	if (m_hideKeyboard) return;
+    QPainter p(this);
+    p.translate(m_shift, MARGIN);
     // just print all visible keys
     for (KTouchBaseKey * key = m_keyList.first(); key; key = m_keyList.next())
-        key->paint(painter);
-}
+        key->paint(p);
 
+/*	// TODO : later
+
+	const KTouchColorScheme& colorScheme = KTouchColorScheme::m_colorSchemes[Prefs::colorScheme()];
+	for (QValueVector<KTouchKey>::iterator it = m_keys.begin(); it != m_keys.end(); ++it) {
+		// determine colors
+    	QColor textColor;
+		if (it->m_type == KTouchKey::NORMAL || it->m_type == KTouchKey::FINGER) {
+			if (is_next_key) {
+				// mark the key as "next"
+				p.setBrush( colorScheme.m_backgroundH );
+				p.setPen( colorScheme.m_frame );
+				textColor = colorScheme.m_textH;
+			}
+			else {
+				p.setBrush( colorScheme.m_background[m_colorIndex] );
+				p.setPen( colorScheme.m_frame );
+				textColor = colorScheme.m_text;
+			};
+		}
+		else {
+    		p.setBrush( colorScheme.m_cBackground );
+			p.setPen( colorScheme.m_cText );
+		}
+
+    	p.setPen(textColor);
+    	p.fillRect(m_xS, m_xS, m_xS, m_xS, p.brush());
+    	p.drawRect(m_xS, m_xS, m_xS, m_xS);
+
+    	p.setFont( m_font );
+    	p.drawText(it->m_xS, it->m_yS, it->m_wS, it->m_hS,
+			QPainter::AlignCenter, m_keyText);
+
+	}
+*/
+	// TODO : later copy pre-rendered and pre-scaled characters to screen
+}
 
 void KTouchKeyboardWidget::resizeEvent(QResizeEvent *) {
 	// kdDebug() << "[KTouchKeyboard::resizeEvent]  Window = " << width() << "x" << height() << endl;
@@ -200,17 +246,20 @@ void KTouchKeyboardWidget::resizeEvent(QResizeEvent *) {
     m_shift = (width() - static_cast<int>(m_keyboardWidth*scale))/2;
     for (KTouchBaseKey * key = m_keyList.first(); key; key = m_keyList.next())
         key->resize(scale);     // resize all keys
+	for (QValueVector<KTouchKey>::iterator it = m_keys.begin(); it != m_keys.end(); ++it) {
+        it->resize(scale);     // resize all keys
+	}
     update();                   // and finally redraw the keyboard
 }
 
 
 void KTouchKeyboardWidget::createDefaultKeyboard() {
     // let's create a default keyboard
-    const int keySpacing = 4;
-    const int keyHeight = 20;
-    const int keyWidth = 20;
-    const int col = keyWidth+keySpacing;
-    const int row = keyHeight+keySpacing;
+    int keySpacing = 4;
+    int keyHeight = 20;
+    int keyWidth = 20;
+    int col = keyWidth+keySpacing;
+    int row = keyHeight+keySpacing;
     // first let's create the "visible" keys, that means all keys that will be displayed
     // Note: purely decorative keys get a key char code of 0!
     m_keyList.clear();
@@ -234,6 +283,7 @@ void KTouchKeyboardWidget::createDefaultKeyboard() {
     m_keyList.append( new KTouchControlKey(8, "BackSpace", 5*col, 0, 2*keyWidth+keySpacing, keyHeight) );
     m_keyboardWidth = 7*col;
     m_keyboardHeight = 5*row;
+
     // now we need to create the connections between the characters that can be typed and the
     // keys that need to be displayed on the keyboard
     // The arguments to the constructor are: keychar, targetkey, fingerkey, controlkey
@@ -258,6 +308,57 @@ void KTouchKeyboardWidget::createDefaultKeyboard() {
     m_connectorList.append( KTouchKeyConnection( 13,  13, '+', 0) );
     updateColours();
     m_currentLayout="number.keyboard";
+
+	// create keyboard geometry for new keyboard data
+
+    int sp = 10;
+    int h = 50;
+    int w = 50;
+    col = w+sp;
+    row = h+sp;
+
+	m_keys.clear();
+	m_keys.append( KTouchKey(                           0,     0, w, h, QString("Num")) );		// 0
+	m_keys.append( KTouchKey(KTouchKey::NORMAL,   	  col,     0, w, h, '/') );			// 1
+	m_keys.append( KTouchKey(KTouchKey::NORMAL, 	2*col,     0, w, h, '*') );			// 2
+	m_keys.append( KTouchKey(KTouchKey::NORMAL, 	3*col,     0, w, h, '-') );			// 3
+	m_keys.append( KTouchKey(KTouchKey::NORMAL,     	0,   row, w, h, '7') );			// 4
+	m_keys.append( KTouchKey(KTouchKey::NORMAL,   	  col,   row, w, h, '8') );			// 5
+	m_keys.append( KTouchKey(KTouchKey::NORMAL, 	2*col,   row, w, h, '9') );			// 6
+	m_keys.append( KTouchKey(KTouchKey::FINGER,     	0, 2*row, w, h, '4') );			// 7  ***
+	m_keys.append( KTouchKey(KTouchKey::FINGER,   	  col, 2*row, w, h, '5') );			// 8  ***
+	m_keys.append( KTouchKey(KTouchKey::FINGER, 	2*col, 2*row, w, h, '6') );			// 9  ***
+	m_keys.append( KTouchKey(KTouchKey::FINGER, 	3*col,   row, w, 2*h+sp, '+') ); 	// 10 ***
+	m_keys.append( KTouchKey(KTouchKey::NORMAL,     	0, 3*row, w, h, '1') );			// 11
+	m_keys.append( KTouchKey(KTouchKey::NORMAL,   	  col, 3*row, w, h, '2') );			// 12
+	m_keys.append( KTouchKey(KTouchKey::NORMAL, 	2*col, 3*row, w, h, '3') );			// 13
+	m_keys.append( KTouchKey(KTouchKey::NORMAL,     	0, 4*row, 2*w+sp, h, '0') );	// 14
+	m_keys.append( KTouchKey(KTouchKey::NORMAL,   	2*col, 4*row, w, h, '.') );			// 15
+	m_keys.append( KTouchKey(KTouchKey::ENTER,  	3*col, 3*row, w, 2*h+sp, 0) ); 		// 16
+	m_keys.append( KTouchKey(KTouchKey::BACKSPACE,  5*col, 0, 2*w+sp, h, 0) ); 			// 17
+	// number the keys for reference
+	for (unsigned int i=0; i<m_keys.size(); ++i)
+		m_keys[i].m_number = i;
+	// create key connections
+	m_keyConnections.clear();
+	// KTouchKeyConnector(char, target, finger, modifier)
+	m_keyConnections.append( KTouchKeyConnector('/',  1,  8, 0) );
+	m_keyConnections.append( KTouchKeyConnector('*',  2,  9, 0) );
+	m_keyConnections.append( KTouchKeyConnector('-',  3, 10, 0) );
+	m_keyConnections.append( KTouchKeyConnector('7',  4,  7, 0) );
+	m_keyConnections.append( KTouchKeyConnector('8',  5,  8, 0) );
+	m_keyConnections.append( KTouchKeyConnector('9',  6,  9, 0) );
+	m_keyConnections.append( KTouchKeyConnector('4',  7,  7, 0) ); // ***
+	m_keyConnections.append( KTouchKeyConnector('5',  8,  8, 0) ); // ***
+	m_keyConnections.append( KTouchKeyConnector('6',  9,  9, 0) ); // ***
+	m_keyConnections.append( KTouchKeyConnector('+', 10, 10, 0) ); // ***
+	m_keyConnections.append( KTouchKeyConnector('1', 11,  7, 0) );
+	m_keyConnections.append( KTouchKeyConnector('2', 12,  8, 0) );
+	m_keyConnections.append( KTouchKeyConnector('3', 13,  9, 0) );
+	m_keyConnections.append( KTouchKeyConnector('0', 14,  7, 0) );
+	m_keyConnections.append( KTouchKeyConnector('.', 15,  9, 0) );
+	m_keyConnections.append( KTouchKeyConnector(QChar(13), 16, 10, 0) );
+	m_keyConnections.append( KTouchKeyConnector(QChar(8), 17, 0, 0) );
 }
 
 
@@ -274,6 +375,7 @@ bool KTouchKeyboardWidget::readKeyboard(const QString& fileName, QString& errorM
     m_connectorList.clear();    // clear the connections
     m_keyboardWidth=0;
     m_keyboardHeight=0;
+	std::set<QChar>  keys;
     // now loop until end of file is reached
     do {
         // skip all empty lines or lines containing a comment (starting with '#')
@@ -295,11 +397,13 @@ bool KTouchKeyboardWidget::readKeyboard(const QString& fileName, QString& errorM
                 w=h=8; // default values for old keyboard files
             m_keyList.append( new KTouchFingerKey(keyAscII, keyText, x+1, y+1, w, h) );
             m_connectorList.append( KTouchKeyConnection(keyAscII, keyAscII, 0, 0) );
+// 			kdDebug() << "read : F : unicode = " << keyAscII << " char = " << QChar(keyAscII) << endl;
         }
         else if (keyType=="ControlKey") {
             lineStream >> keyText >> x >> y >> w >> h;
             m_keyList.append( new KTouchControlKey(keyAscII, keyText, x+1, y+1, w-2, h-2) );
             m_connectorList.append( KTouchKeyConnection(keyAscII, keyAscII, 0, 0) );
+// 			kdDebug() << "read : C : unicode = " << keyAscII << " char = " << keyText << endl;
         }
         else if (keyType=="NormalKey") {
             int fingerCharCode;
@@ -308,30 +412,65 @@ bool KTouchKeyboardWidget::readKeyboard(const QString& fileName, QString& errorM
             // retrieve the finger key with the matching char
             m_keyList.append( new KTouchNormalKey(keyAscII, keyText, x+1, y+1, w, h) );
             m_connectorList.append( KTouchKeyConnection(keyAscII, keyAscII, fingerCharCode, 0) );
+// 			kdDebug() << "read : N : unicode = " << keyAscII << " char = " << QChar(keyAscII) << endl;
         } else if (keyType=="HiddenKey") {
             int targetChar, fingerChar, controlChar;
             lineStream >> targetChar >> fingerChar >> controlChar;
             m_connectorList.append( KTouchKeyConnection(keyAscII, targetChar, fingerChar, controlChar) );
+//			kdDebug() << "read : H : unicode = " << keyAscII << " char = " << QChar(keyAscII) << " target = " << targetChar << " finger = " << fingerChar << " control = " << controlChar << endl;
+			
         }
         else {
             errorMsg = i18n("Missing key type in line '%1'.").arg(line);
             return false;
         }
+		if (keys.find(keyAscII)!=keys.end()) {
+			kdDebug() << "WARNING: Duplicate entry for char '"+keyText+"' with Unicode " << keyAscII << endl;
+		}
+		else
+			keys.insert(keyAscII);
+
+		keys.insert(keyAscII);
+
+
         // calculate the maximum extent of the keyboard on the fly...
         m_keyboardWidth = std::max(m_keyboardWidth, x+w);
         m_keyboardHeight = std::max(m_keyboardHeight, y+h);
     } while (!in.atEnd() && !line.isNull());
+//	kdDebug() << "showing all unicode numbers in this file" << endl;
+/*	for (std::set<QChar>::iterator it = keys.begin(); it != keys.end(); ++it)
+		kdDebug() << *it << endl;
+*/
+//	kdDebug() << "num chars = " << keys.size() << endl;
+//	kdDebug() << "num key connections = " << m_connectorList.size() << endl;
+
     updateColours();
     return (!m_keyList.isEmpty());  // empty file means error
 }
 
 
 void KTouchKeyboardWidget::updateColours() {
-    // loop over all key connections
+//	kdDebug() << "KTouchKeyboardWidget::updateColours()" << endl;
+    // old functionality : loop over all key connections
+	m_keyCharMap.clear();
+	unsigned int counter = 0;
     for (QValueList<KTouchKeyConnection>::iterator it = m_connectorList.begin(); it!=m_connectorList.end(); ++it) {
+		// store finger and target characters
         QChar fingerChar = (*it).m_fingerKeyChar;
-        if (fingerChar == QChar(0)) continue;
-        QChar targetChar = (*it).m_targetKeyChar;
+        QChar targetChar = (*it).m_targetKeyChar; // this is the _base_ character of the key that needs to be highlighted
+        QChar ch = (*it).m_keyChar;
+
+/*		kdDebug() << "Key #"<<++counter<<": " << ch << "(" << ch.unicode() << ") " 
+				  << "target = " << targetChar << "(" << targetChar.unicode() << ") " 
+				  << "finger = " << fingerChar << "(" << fingerChar.unicode() << ")" << endl;
+*/
+		m_keyCharMap[ch] = -1;
+
+        if (fingerChar == QChar(0)) {
+//			kdDebug() << "skipped char = " << targetChar << endl;
+			continue; // skips keys that don't have finger keys assigned
+		}
+
         KTouchBaseKey * self=NULL;
         KTouchBaseKey * colorSource=NULL;
         // loop over all keys to find the key pointers
@@ -339,25 +478,55 @@ void KTouchKeyboardWidget::updateColours() {
             if (key->m_keyChar==targetChar) self=key;
             else if (key->m_keyChar==fingerChar) colorSource=key;
         }
+		// ok, by now we should have found a finger and target char pointer
         if (self && colorSource) {
-            if (self->type()!=KTouchBaseKey::NORMAL_KEY)
-                continue;
+// 			kdDebug() << "Key " << ++counter << " keychar = " << ch << " target = " << targetChar << "  finger = " << fingerChar << endl;
+			// skip target keys that are actually control, finger or hidden keys
+            if (self->type()!=KTouchBaseKey::NORMAL_KEY)  continue;
+			// try to downcast to get a normal key pointer
             KTouchNormalKey *nk = dynamic_cast<KTouchNormalKey*>(self);
+			// skip if we couldn't downcast
+			if (!nk) {
+				kdDebug() << "Couldn't downcast to normal key for targer char = " << targetChar << endl;
+				continue;
+			}
+			// if our color source is not a valid finger key, skip with a warning
             if (colorSource->type()!=KTouchBaseKey::FINGER_KEY) {
                 kdDebug() << "[KTouchKeyboard::updateColours]  Colour source key '" << colorSource->m_keyText
                           << "' is not a finger key!" << endl;
-                if (nk) {
-                    nk->m_colorIndex = 0;
-                }
-                continue;
-            }
-            if (nk) {
-                KTouchFingerKey *fk = dynamic_cast<KTouchFingerKey*>(colorSource);
-                if (fk) {
-                    nk->m_colorIndex = fk->m_colorIndex;
-                }
+				continue;
+			}
+			// finally store the color code
+            KTouchFingerKey *fk = dynamic_cast<KTouchFingerKey*>(colorSource);
+            if (fk) {
+				nk->m_colorIndex = fk->m_colorIndex;
+				m_keyCharMap[ch] = fk->m_colorIndex;
+//				kdDebug() << "char = " << targetChar << " index = " << fk->m_colorIndex << endl;
             }
         }
     }
+//	kdDebug() << "Colormap has " << m_keyCharMap.count() << " entries" << endl;
+
+/*
+	// new functionality
+	m_keyMap.clear();
+	m_colorMap.clear();
+	for (unsigned int i=0; i<m_keys.size(); ++i)
+		m_keyMap[i] = -1;
+	int c_index = 0;
+    for (QValueVector<KTouchKeyConnector>::iterator it = m_keyConnections.begin();
+		it!=m_keyConnections.end(); ++it)
+	{
+		if (it->m_targetKeyIndex == -1) continue;
+		int n = it->m_targetKeyIndex;
+		switch (m_keys[n].m_type) {
+			case KTouchKey::NORMAL : m_keyMap[n] = it->m_fingerKeyIndex; break;
+			case KTouchKey::FINGER : m_keyMap[n] = it->m_fingerKeyIndex; 
+									 m_colorMap[n] = c_index++;
+									 c_index %= 8; break;
+			default : ;
+		}
+	}
+*/
 }
 
