@@ -30,8 +30,10 @@ bool KTouchLecture::load(QWidget * window, const KURL& url) {
     if (KIO::NetAccess::download(url, target, window)) {
         // Ok, that was successful, store the lectureURL and read the file
         QFile infile(target);
-        if ( !infile.open( IO_ReadOnly ) )
+        if ( !infile.open( IO_ReadOnly ) ) {
+    		KIO::NetAccess::removeTempFile(target);
             return false;   // Bugger it... couldn't open it...
+		}
         QTextStream in( &infile );
         result = readLecture(in);
     };
@@ -48,8 +50,10 @@ bool KTouchLecture::loadXML(QWidget * window, const KURL& url) {
     if (KIO::NetAccess::download(url, target, window)) {
         // Ok, that was successful, store the lectureURL and read the file
         QFile infile(target);
-        if ( !infile.open( IO_ReadOnly ) )
+        if ( !infile.open( IO_ReadOnly ) ) {
+		    KIO::NetAccess::removeTempFile(target);
             return false;   // Bugger it... couldn't open it...
+		}
 		QDomDocument doc;
 		doc.setContent( &infile );
         result = readLecture(doc);
@@ -97,7 +101,8 @@ bool KTouchLecture::saveXML(QWidget * window, const KURL& url) const {
 
 void KTouchLecture::createDefault() {
     m_lectureData.clear();      // remove everything else
-    m_title = i18n("A new lecture...");
+    m_title = i18n("A default lecture...");
+    m_fontSuggestions = "Monospace";
     KTouchLevelData miniLevel;  // create the level which is by default a mini-level
     m_lectureData.push_back( miniLevel );
 }
@@ -192,7 +197,7 @@ bool KTouchLecture::readLecture(QDomDocument& doc) {
 		level.readLevel(entries.item(i));
         m_lectureData.push_back(level);
 	}
-    if (m_lectureData.size()>1)
+    if (m_lectureData.size()>0)
         return true;  // all ok
     else {
         // Hmm, no levels in the file. So we create our default mini level and report an error.
