@@ -173,7 +173,7 @@ public:
    bool isGroupVerb();
    /** returns the group number to which the verb belongs
     */
-   int getGroup() { return group; };
+   int getGroup() { return group; }
    /** sets the field regular corresponding to b
     */
    void setGroup(const int g);
