@@ -24,9 +24,6 @@
  *                                                                         *
  ***************************************************************************/
 
-#define SORT_ALPHA  I18N_NOOP("&Sort alphabetically")
-#define SORT_NUM    I18N_NOOP("Sort by &index")
-
 #include "kvoctrain.h"
 #include "query-dialogs/RandomQueryDlg.h"
 #include "query-dialogs/MCQueryDlg.h"
@@ -42,6 +39,9 @@
 #include <kstandarddirs.h>
 #include <kiconloader.h>
 
+static const char *SORT_ALPHA =  I18N_NOOP("&Sort alphabetically");
+static const char *SORT_NUM =  I18N_NOOP("Sort by &index");
+
 void kvoctrainApp::slotHeaderMenu(int header, int x, int y) /*FOLD00*/
 {
   delete header_m;
