@@ -186,8 +186,15 @@ void KVocTrainTable::updateContents(int row, int col)
     nrows = 0;
     ncols = 1+KV_EXTRA_COLS;
   }
-  if (nrows != numRows())
+  if (nrows != numRows()) {
+    // remember number of new rows (typically one)
+    unsigned int new_rows = QMAX(0, nrows - numRows());
+    // adjust number of rows
     setNumRows(nrows);
+    // adjust row heights for added rows
+    for (int i=nrows-new_rows; i<nrows; ++i)
+      setRowHeight(i, fontMetrics().lineSpacing());
+  }
   if (ncols != numCols())
     setNumCols(ncols);
   current_row = QMIN(current_row, QMAX(0, numRows()-1));
