@@ -45,15 +45,19 @@ static const char version[]     = KVOCTRAIN_VERSION_STRING;
                        version,
                        description,
                        KAboutData::License_GPL,
-                       I18N_NOOP("(c) 1999-2002\tEwald Arnold\n"
-                       "(c) 2001-2002\tThe KDE team\n"
-                       "(c) 2004-2005\tPeter Hedlund\n"),
+                       I18N_NOOP("© 1999-2002\tEwald Arnold\n"
+                       "© 2001-2002\tThe KDE team\n"
+                       "© 2004-2007\tPeter Hedlund\n"
+                       "© 2007     \tFrederik Gladhorn\n"),
                        I18N_NOOP("Helps you train your vocabulary"),
                        "http://edu.kde.org/kvoctrain",
                        "submit@bugs.kde.org");
 
+  aboutData.addAuthor("Frederik Gladhorn",
+                      I18N_NOOP("Current Maintainer"), "frederik.gladhorn@kdemail.net");
+
   aboutData.addAuthor("Peter Hedlund",
-                      I18N_NOOP("Current Maintainer"), "peter@peterandlinda.com");
+                      I18N_NOOP("Former Maintainer and Countless Improvements"), "peter.hedlund@kdemail.net");
 
   aboutData.addAuthor("Ewald Arnold", I18N_NOOP("Original Author"), "kvoctrain@ewald-arnold.de",
                       "http://www.ewald-arnold.de" );
@@ -77,7 +81,7 @@ static const char version[]     = KVOCTRAIN_VERSION_STRING;
                       I18N_NOOP("Tool to create lists with ISO639 codes"));
 
   aboutData.addCredit("Andreas Neuper",
-                      I18N_NOOP("Converter script \"langen2kvtml\" (download files at http://www.vokabeln.de/files.htm)"));
+                      I18N_NOOP("Converter script \"langen2kvtml\" \nDownload files at http://www.vokabeln.de/files.htm"));
 
    aboutData.addCredit("Dennis Haney",
                       I18N_NOOP("Patch to implement Leitner learning method"));
